@@ -10,9 +10,9 @@ def check_cluster_ready(name: str, path: str, api_client: ApiClient) -> bool:
     print(f'\tChecking cluster {name}')
     daemonset_check = check_only_one_daemonset(path)
     if daemonset_check:
-        console.print("\t\tonly one daemonset:................. [bold green]SUCCESS")
+        console.print("\t\t[grey66]only one daemonset[/grey66]:................. [bold green]SUCCESS")
     else:
-        console.print("\t\tonly one daemonset:................. [bold red]FAILED")
+        console.print("\t\t[grey66]only one daemonset[/grey66]:................. [bold red]FAILED")
         return False
 
     return True
