@@ -75,8 +75,9 @@ def get_cluster_name(c):
 
 
 def update_prebid_tag(path: str, tag: str):
+    console = Console()
     path += "/namespace/api/pbs.prod.tag"
-    print(f"Updating prebid tag to {tag} in file: {path}")
+    console.print(f"Updating prebid tag to [bold blue_violet]{tag}[/bold blue_violet] in file: [bold light_steel_blue1]{path}[/bold light_steel_blue1]")
     with open(path, "w") as f:
         f.write(tag)
 
@@ -218,7 +219,7 @@ def main():
             console.print('[orange3]please send this to Dimitri Wyzlic on Slack!')
             return 1
     except KeyboardInterrupt:
-        console.print("\n\n[bold red]Interrupted by user (keyboard -> CTRL-C)")
+        console.print("\n\n[bold red]Interrupted by user (CTRL-C)")
     return 0
 
 
